==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fIastore.h <==
// class soot.coffi.Instruction_Iastore

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 69b1a41379d1ba68 soot_coffi_Instruction__5fIastore
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fIastore_H_
#define _JC_soot_coffi_Instruction__5fIastore_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fIastore$sub_refs	_jc_soot_coffi_Instruction__5fIastore$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fIastore$sub_nonrefs	_jc_soot_coffi_Instruction__5fIastore$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIastore$refs	_jc_soot_coffi_Instruction__5fIastore$refs;
typedef struct _jc_soot_coffi_Instruction__5fIastore$nonrefs	_jc_soot_coffi_Instruction__5fIastore$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIastore$object	_jc_soot_coffi_Instruction__5fIastore$object;

typedef const struct _jc_soot_coffi_Instruction__5fIastore$vmethods	_jc_soot_coffi_Instruction__5fIastore$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fIastore$vtable	_jc_soot_coffi_Instruction__5fIastore$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fIastore$vtype	_jc_soot_coffi_Instruction__5fIastore$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fIastore$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fIastore$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fIastore$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fIastore$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fIastore$vmethods	soot_coffi_Instruction__5fIastore;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fIastore$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fIastore$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIastore$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIastore$refs {
    _jc_soot_coffi_Instruction__5fIastore$sub_refs	soot_coffi_Instruction__5fIastore;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIastore$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIastore$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fIastore$sub_nonrefs	soot_coffi_Instruction__5fIastore;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fIastore$object {
	_jc_soot_coffi_Instruction__5fIastore$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fIastore$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fIastore$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fIastore$vtype _jc_soot_coffi_Instruction__5fIastore$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fIastore, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fIastore$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fIastore_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fIastore.h <==
// class soot.coffi.Instruction_Iastore

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 69b1a41379d1ba68 soot_coffi_Instruction__5fIastore
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fIastore_H_
#define _JC_soot_coffi_Instruction__5fIastore_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fIastore$sub_refs	_jc_soot_coffi_Instruction__5fIastore$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fIastore$sub_nonrefs	_jc_soot_coffi_Instruction__5fIastore$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIastore$refs	_jc_soot_coffi_Instruction__5fIastore$refs;
typedef struct _jc_soot_coffi_Instruction__5fIastore$nonrefs	_jc_soot_coffi_Instruction__5fIastore$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIastore$object	_jc_soot_coffi_Instruction__5fIastore$object;

typedef const struct _jc_soot_coffi_Instruction__5fIastore$vmethods	_jc_soot_coffi_Instruction__5fIastore$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fIastore$vtable	_jc_soot_coffi_Instruction__5fIastore$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fIastore$vtype	_jc_soot_coffi_Instruction__5fIastore$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fIastore$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fIastore$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fIastore$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fIastore$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fIastore$vmethods	soot_coffi_Instruction__5fIastore;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fIastore$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fIastore$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIastore$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIastore$refs {
    _jc_soot_coffi_Instruction__5fIastore$sub_refs	soot_coffi_Instruction__5fIastore;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIastore$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIastore$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fIastore$sub_nonrefs	soot_coffi_Instruction__5fIastore;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fIastore$object {
	_jc_soot_coffi_Instruction__5fIastore$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fIastore$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fIastore$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fIastore$vtype _jc_soot_coffi_Instruction__5fIastore$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fIastore, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fIastore$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fIastore_H_ */
